| Title: | An 'Rcpp' Interface to Active Bindings |
|---|---|
| Description: | Provides an easy way to fill an environment with active bindings that call a C++ function. |
| Authors: | Kirill Müller [aut, cre] (ORCID: <https://orcid.org/0000-0002-1416-3412>), RStudio [cph] |
| Maintainer: | Kirill Müller <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.2.4.9008 |
| Built: | 2026-05-24 02:46:23 UTC |
| Source: | https://github.com/krlmlr/bindrcpp |
Provides an easy way to fill an environment with active bindings that call a C++ function.
Use LinkingTo: bindrcpp in DESCRIPTION and
#include <bindrcpp.h> in your C++ headers and/or modules to access the
C++ functions provided by this package:
create_env_string() creates an environment with active bindings, with
names given as a character vector. Access of these bindings triggers a
call to a C++ function with a fixed signature (GETTER_FUNC_STRING);
this call contains the name of the binding (as character) and an arbitrary
payload (PAYLOAD, essentially a wrapped void*).
create_env_symbol() is similar, the callback function accepts the name of
the binding as symbol instead of character (GETTER_FUNC_SYMBOL).
populate_env_string() and populate_env_symbol() populate an existing
environment instead of creating a new one.
Maintainer: Kirill Müller [email protected] (ORCID)
Authors:
Kirill Müller [email protected] (ORCID)
Other contributors:
RStudio [copyright holder]
Useful links:
Report bugs at https://github.com/krlmlr/bindrcpp/issues